ALTER TABLE `AuthUsers`
    CHANGE `CreatedAt` `CreatedAt` DATETIME(6) NULL DEFAULT CURRENT_TIMESTAMP(6);

ALTER TABLE `AuthUsers`
    CHANGE `LastModifiedAt` `LastModifiedAt` DATETIME(6) NULL DEFAULT CURRENT_TIMESTAMP(6) ON UPDATE CURRENT_TIMESTAMP(6);

CREATE TABLE IF NOT EXISTS `AuthUsersHistory`
(
    `Id`                     BIGINT(20)  NOT NULL,
    `FirstName`              VARCHAR(255)         DEFAULT NULL,
    `LastName`               VARCHAR(255)         DEFAULT NULL,
    `EMail`                  VARCHAR(255)         DEFAULT NULL,
    `Password`               VARCHAR(255)         DEFAULT NULL,
    `PasswordSalt`           VARCHAR(255)         DEFAULT NULL,
    `RefreshToken`           VARCHAR(255)         DEFAULT NULL,
    `ConfirmationId`         VARCHAR(255)         DEFAULT NULL,
    `ForgotPasswordId`       VARCHAR(255)         DEFAULT NULL,
    `OAuthId`                VARCHAR(255)         DEFAULT NULL,
    `RefreshTokenExpiryTime` DATETIME(6) NOT NULL,
    `AuthRole`               BIGINT(11)  NOT NULL DEFAULT 0,
    `Deleted`                BOOL                 DEFAULT FALSE,
    `DateFrom`               DATETIME(6) NOT NULL,
    `DateTo`                 DATETIME(6) NOT NULL
);

DROP TRIGGER IF EXISTS `TR_AuthUsersUpdate`;

CREATE TRIGGER `TR_AuthUsersUpdate`
    AFTER UPDATE
    ON `AuthUsers`
    FOR EACH ROW
BEGIN
    INSERT INTO `AuthUsersHistory` (
        `Id`, `FirstName`, `LastName`, `EMail`, `Password`, `PasswordSalt`,
        `RefreshToken`, `ConfirmationId`, `ForgotPasswordId`, `OAuthId`,
        `RefreshTokenExpiryTime`, `AuthRole`, `DateFrom`, `DateTo`
    )
    VALUES (
        OLD.Id, OLD.FirstName, OLD.LastName, OLD.EMail, OLD.Password, OLD.PasswordSalt, OLD.RefreshToken,
        OLD.ConfirmationId, OLD.ForgotPasswordId, OLD.OAuthId, OLD.RefreshTokenExpiryTime, OLD.AuthRole,
        OLD.LastModifiedAt, CURRENT_TIMESTAMP(6)
    );
END;

DROP TRIGGER IF EXISTS `TR_AuthUsersDelete`;

CREATE TRIGGER `TR_AuthUsersDelete`
    AFTER DELETE
    ON `AuthUsers`
    FOR EACH ROW
BEGIN
    INSERT INTO `AuthUsersHistory` (
        `Id`, `FirstName`, `LastName`, `EMail`, `Password`, `PasswordSalt`, `RefreshToken`,
        `ConfirmationId`, `ForgotPasswordId`, `OAuthId`, `RefreshTokenExpiryTime`,
        `AuthRole`, `Deleted`, `DateFrom`, `DateTo`
    )
    VALUES (
        OLD.Id, OLD.FirstName, OLD.LastName, OLD.EMail, OLD.Password, OLD.PasswordSalt, OLD.RefreshToken,
        OLD.ConfirmationId, OLD.ForgotPasswordId, OLD.OAuthId, OLD.RefreshTokenExpiryTime, OLD.AuthRole, TRUE,
        OLD.LastModifiedAt, CURRENT_TIMESTAMP(6)
    );
END;