from cpl_core.dependency_injection import ServiceProviderABC
from cpl_discord.service import DiscordBotServiceABC

from bot_data.abc.history_table_abc import HistoryTableABC


class ClientHistory(HistoryTableABC):
    def __init__(
        self,
        dc_id: int,
        smc: int,
        rmc: int,
        dmc: int,
        rcc: int,
        muc: int,
        server: int,
        deleted: bool,
        date_from: str,
        date_to: str,
        id=0,
    ):
        HistoryTableABC.__init__(self)

        self._client_id = id
        self._discord_client_id = dc_id
        self._sent_message_count = smc
        self._received_message_count = rmc
        self._deleted_message_count = dmc
        self._received_command_count = rcc
        self._moved_users_count = muc
        self._server = server

        self._deleted = deleted
        self._date_from = date_from
        self._date_to = date_to

    @property
    def id(self) -> int:
        return self._client_id

    @property
    def discord_id(self) -> int:
        return self._discord_client_id

    @property
    @ServiceProviderABC.inject
    def name(self, bot: DiscordBotServiceABC) -> str:
        return bot.user.name

    @property
    def sent_message_count(self) -> int:
        return self._sent_message_count

    @property
    def received_message_count(self) -> int:
        return self._received_message_count

    @property
    def deleted_message_count(self) -> int:
        return self._deleted_message_count

    @property
    def received_command_count(self) -> int:
        return self._received_command_count

    @property
    def moved_users_count(self) -> int:
        return self._moved_users_count

    @property
    def server(self) -> int:
        return self._server
