from typing import Type

from cpl_core.database.context import DatabaseContextABC
from cpl_query.extension import List

from bot_data.abc.history_table_abc import HistoryTableABC
from bot_data.abc.table_with_id_abc import TableWithIdABC
from bot_graphql.abc.data_query_abc import DataQueryABC


class DataQueryWithHistoryABC(DataQueryABC):
    def __init__(
        self,
        name: str,
        table_name: str,
        history_type: Type[HistoryTableABC],
        db: DatabaseContextABC,
    ):
        self._table_name = table_name
        self._history_type = history_type
        self._db = db

        DataQueryABC.__init__(self, name)

        self.set_field("history", self.resolve_history)

    def resolve_history(self, entry: TableWithIdABC, *_):
        history = List(self._history_type)

        results = self._db.select(
            f"""
            SELECT *
            FROM {self._table_name}
            WHERE Id = {entry.id}
            ORDER BY DateTo DESC;
            """
        )

        for result in results:
            history.add(self._history_type(*result[1:], result[0]))

        return history
