from cpl_core.database.context import DatabaseContextABC
from cpl_core.logging import LoggerABC
from cpl_discord.events import OnGuildJoinABC
from cpl_discord.service import DiscordBotServiceABC
from discord import Guild

from bot_data.abc.server_config_repository_abc import ServerConfigRepositoryABC
from bot_data.abc.server_repository_abc import ServerRepositoryABC
from bot_data.model.server import Server
from bot_data.service.seeder_service import SeederService


class BaseOnGuildJoinEvent(OnGuildJoinABC):
    def __init__(
        self,
        logger: LoggerABC,
        bot: DiscordBotServiceABC,
        servers: ServerRepositoryABC,
        server_config: ServerConfigRepositoryABC,
        db: DatabaseContextABC,
        seeder: SeederService,
    ):
        OnGuildJoinABC.__init__(self)

        self._logger = logger
        self._bot = bot
        self._servers = servers
        self._server_config = server_config
        self._db = db
        self._seeder = seeder

    async def on_guild_join(self, guild: Guild):
        if self._servers.find_server_by_discord_id(guild.id) is None:
            self._servers.add_server(Server(guild.id))
            self._db.save_changes()

        await self._seeder.seed()
        self._logger.debug(__name__, "Seeded technician config")
