import discord
from cpl_core.configuration import ConfigurationABC
from cpl_core.database.context import DatabaseContextABC
from cpl_core.logging import LoggerABC
from cpl_discord.events import OnVoiceStateUpdateABC

from bot_core.helper.event_checks import EventChecks
from bot_data.abc.server_repository_abc import ServerRepositoryABC
from bot_data.abc.user_repository_abc import UserRepositoryABC
from modules.base.service.event_service import EventService


class BaseOnVoiceStateUpdateEventScheduledEventBonus(OnVoiceStateUpdateABC):
    def __init__(
        self,
        config: ConfigurationABC,
        logger: LoggerABC,
        servers: ServerRepositoryABC,
        users: UserRepositoryABC,
        events: EventService,
        db: DatabaseContextABC,
    ):
        OnVoiceStateUpdateABC.__init__(self)
        self._config = config
        self._logger = logger
        self._servers = servers
        self._users = users
        self._events = events
        self._db = db

        self._logger.info(__name__, f"Module {type(self)} loaded")

    @EventChecks.check_is_ready()
    async def on_voice_state_update(
        self,
        member: discord.Member,
        before: discord.VoiceState,
        after: discord.VoiceState,
    ):
        self._logger.debug(__name__, f"Module {type(self)} started")
        if member.bot or after.channel is None:
            self._logger.debug(__name__, f"Module {type(self)} stopped")
            return

        active_event = self._events.get_active_event_by_channel_id(after.channel.id)
        if active_event is None:
            self._logger.debug(__name__, f"Module {type(self)} stopped")
            return

        self._events.give_xp_for_event_participation(member, active_event)

        self._logger.debug(__name__, f"Module {type(self)} stopped")
