from cpl_core.configuration import ConfigurationABC
from cpl_discord.command import DiscordCommandABC
from cpl_translation import TranslatePipe
from discord.ext import commands
from discord.ext.commands import Context

from bot_core.abc.client_utils_abc import ClientUtilsABC
from bot_core.abc.message_service_abc import MessageServiceABC
from bot_core.configuration.feature_flags_enum import FeatureFlagsEnum
from bot_core.configuration.feature_flags_settings import FeatureFlagsSettings
from bot_core.helper.command_checks import CommandChecks
from bot_core.logging.command_logger import CommandLogger
from bot_data.model.server_config import ServerConfig
from modules.permission.abc.permission_service_abc import PermissionServiceABC
from modules.short_role_name.service.short_role_name_service import ShortRoleNameService


class ShortRoleNameCheckCommand(DiscordCommandABC):
    def __init__(
        self,
        logger: CommandLogger,
        config: ConfigurationABC,
        message_service: MessageServiceABC,
        permissions: PermissionServiceABC,
        client_utils: ClientUtilsABC,
        translate: TranslatePipe,
        short_role_name_service: ShortRoleNameService,
    ):
        DiscordCommandABC.__init__(self)

        self._logger = logger
        self._config = config
        self._message_service = message_service
        self._permissions = permissions
        self._client_utils = client_utils
        self._t = translate
        self._service = short_role_name_service

        self._logger.trace(__name__, f"Loaded command service: {type(self).__name__}")

    @commands.hybrid_command(name="short-role-name-check")
    @commands.guild_only()
    @CommandChecks.check_is_ready()
    @CommandChecks.check_is_member_moderator()
    async def short_role_name_check(self, ctx: Context):
        self._logger.debug(__name__, f"Received command purge {ctx}")
        if ctx.guild is None:
            return

        settings: ServerConfig = self._config.get_configuration(f"ServerConfig_{ctx.guild.id}")
        if not FeatureFlagsSettings.get_flag_from_dict(settings.feature_flags, FeatureFlagsEnum.short_role_name):
            await self._message_service.send_ctx_msg(ctx, self._t.transform("common.feature_not_activated"))
            return

        for member in ctx.guild.members:
            await self._service.check_short_role_names(member)

        await self._message_service.send_ctx_msg(ctx, self._t.transform("modules.short_role_name.checked_message"))

        self._logger.trace(__name__, f"Finished purge command")
